{ Marco Cantu' (author of Master Delphi x and Delphi Developers Handbook has   }
{ released an excellent run-time object inspector tool as freeware.  It can be }
{ found in the Delphi Developers Handbook (highly recommended) and on his web  }
{ site at http://www.marcocantu.com.  If you have this installed, you can      }
{ enable the following define (remove the period) to use it in the demo.       }
{ It is for Delphi 3 only, but I think he has a beta for Delphi 2.             }
{.$DEFINE DFS_RUN_TIME_DEBUGGER}

unit Main;

interface

uses
  SysUtils, Messages, Classes, Graphics, Controls,
  {$IFDEF DFS_WIN32}
  Windows,
  {$ELSE}
  {$ENDIF}
  {$IFDEF DFS_RUN_TIME_DEBUGGER}
  DdhObjDb,
  {$ENDIF}
  Forms, Dialogs, StdCtrls, Buttons, ExtCtrls, Menus, MRUFList;

type
  TMainForm = class(TForm)
    SpeedBar: TPanel;
    SpeedButton1: TSpeedButton;
    SpeedButton2: TSpeedButton;
    SpeedButton3: TSpeedButton;
    SpeedButton4: TSpeedButton;
    SpeedButton5: TSpeedButton;
    SpeedButton6: TSpeedButton;
    SpeedButton7: TSpeedButton;
    MainMenu: TMainMenu;
    FileMenu: TMenuItem;
    FileNewItem: TMenuItem;
    FileOpenItem: TMenuItem;
    FileSaveItem: TMenuItem;
    FileSaveAsItem: TMenuItem;
    FileExitSeparator: TMenuItem;
    FileExitItem: TMenuItem;
    EditMenu: TMenuItem;
    EditUndoItem: TMenuItem;
    N2: TMenuItem;
    EditCutItem: TMenuItem;
    EditCopyItem: TMenuItem;
    EditPasteItem: TMenuItem;
    WindowMenu: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    MRUFileList: TdfsMRUFileList;
    procedure FormCreate(Sender: TObject);
    procedure FileNew(Sender: TObject);
    procedure FileOpen(Sender: TObject);
    procedure FileSave(Sender: TObject);
    procedure FileSaveAs(Sender: TObject);
    procedure FileExit(Sender: TObject);
    procedure EditUndo(Sender: TObject);
    procedure EditCut(Sender: TObject);
    procedure EditCopy(Sender: TObject);
    procedure EditPaste(Sender: TObject);
    procedure WindowTile(Sender: TObject);
    procedure WindowCascade(Sender: TObject);
    procedure WindowArrange(Sender: TObject);
    procedure MRUFileListMRUItemClick(Sender: TObject; AFilename: string);
    procedure dfsMRUFileList1MRUItemClick(Sender: TObject;
      AFilename: String);
  end;

var
  MainForm: TMainForm;

implementation

uses
  {$IFDEF DFS_WIN32}
  Registry,
  {$ENDIF}
  Child;

{$R *.DFM}

procedure TMainForm.FormCreate(Sender: TObject);
begin
  {$IFDEF DFS_RUN_TIME_DEBUGGER}
  TDdhObjectDebugger.Create(Self);
  {$ENDIF}
end;

procedure TMainForm.FileNew(Sender: TObject);
begin
  with TChildForm.Create(Self) do
    Caption := '[untitled]';
end;

procedure TMainForm.FileOpen(Sender: TObject);
begin
  if OpenDialog.Execute then
    with TChildForm.Create(Self) do begin
      Memo.Lines.LoadFromFile(OpenDialog.FileName);
      Caption := OpenDialog.FileName;
    end;
  end;

procedure TMainForm.FileSave(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do begin
    if Caption = '[untitled]' then
      FileSaveAs(Sender)
    else
      Memo.Lines.SaveToFile(Caption);
  end;
end;

procedure TMainForm.FileSaveAs(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  if SaveDialog.Execute then
  begin
    (ActiveMDIChild as TChildForm).Caption := SaveDialog.FileName;
    FileSave(Sender);
  end;
end;

procedure TMainForm.FileExit(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.EditUndo(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.Perform(WM_UNDO, 0, 0);
end;

procedure TMainForm.EditCut(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.CutToClipboard;
end;

procedure TMainForm.EditCopy(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.CopyToClipboard
end;

procedure TMainForm.EditPaste(Sender: TObject);
begin
  if ActiveMDIChild = NIL then exit;
  with ActiveMDIChild as TChildForm do
    Memo.PasteFromClipboard;
end;

procedure TMainForm.WindowTile(Sender: TObject);
begin
  Tile;
end;

procedure TMainForm.WindowCascade(Sender: TObject);
begin
  Cascade;
end;

procedure TMainForm.WindowArrange(Sender: TObject);
begin
  ArrangeIcons;
end;

procedure TMainForm.MRUFileListMRUItemClick(Sender: TObject; AFilename: string);
begin
  with TChildForm.Create(Self) do begin
    Memo.Lines.LoadFromFile(AFileName);
    Caption := AFileName;
  end;
end;

procedure TMainForm.dfsMRUFileList1MRUItemClick(Sender: TObject;
  AFilename: String);
begin
  with TChildForm.Create(Self) do begin
    Memo.Lines.LoadFromFile(AFileName);
    Caption := AFileName;
  end;
end;

end.

